# utils.py


class Colour(object):
    """
    Color output in terminal so warnings/errors stick out.
    """
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

    def __init__(self):
        raise NotImplementedError

    @classmethod
    def text(cls, txt, status=None):
        """
        Colorize specific text

        @txt:       text printed to console
        @status:    the type of status depends on the color

        returns:
            colorized text string
        """
        if status == 'fail':
            return cls.FAIL + txt + cls.ENDC
        elif status == 'ok':
            return cls.OKGREEN + txt + cls.ENDC
        elif status == 'warn':
            return cls.WARNING + txt + cls.ENDC
        else:
            return txt



import random
import StringIO
import sys

from django.conf import settings
from django.test import TestCase, override_settings

from django_spam import SPAM_ROUTES


class DjangoSpamTestCase(TestCase):
    def test_redirect_random_route(self):
        response = self.client.get('/'+random.choice(SPAM_ROUTES))
        self.assertEqual(response.status_code, 302)

    def test_add_spam_routes_in_settings(self):
        spam_routes = getattr(settings, 'SPAM_ROUTES', [])
        response = self.client.get('/'+spam_routes[-1])
        self.assertEqual(response.status_code, 302)

    def test_excluded_routes(self):
        excluded_routes = getattr(settings, 'EXCLUDED_ROUTES', [])
        response = self.client.get('/'+excluded_routes[-1])
        self.assertEqual(response.status_code, 200)

    @override_settings(EXCLUDED_ROUTES=['notinlist.html',])
    def test_excluded_routes_contains_non_existent_spam_route(self):
        # create string object, redirect to stdout, reload package, then reset redirect
        capturedOutput = StringIO.StringIO()
        sys.stdout = capturedOutput
        import django_spam
        reload(django_spam)
        sys.stdout = sys.__stdout__

        captured_output = capturedOutput.getvalue()
        self.assertIn('Warning:', captured_output) and \
        self.assertIn('is not included in django_spam.SPAM_ROUTES.', captured_output)



from django_spam.utils import Colour

from django.conf import settings
from django.test import TestCase, override_settings


class DjangoSpamUtilsTestCase(TestCase):
    """
    We use assertIn due to unicode preceding and trailing text...for
    visual clarity.
    """
    def test_fail_text(self):
        fail_text = Colour.text('Fail text.', 'fail')
        self.assertIn('Fail text.', fail_text)

    def test_ok_text(self):
        ok_text = Colour.text('Ok text.', 'ok')
        self.assertIn('Ok text.', ok_text)

    def test_warn_text(self):
        warn_text = Colour.text('Warn text.', 'warn')
        self.assertIn('Warn text.', warn_text)

    def test_no_status_text(self):
        warn_text = Colour.text('Warn text.')  # pylint: disable=no-value-for-parameter
        self.assertIn('Warn text.', warn_text)

    def test_not_implemented_error(self):
        with self.assertRaises(NotImplementedError):
            Colour()



import os.path

INSTALLED_APPS = [
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    # 'tests',
    # 'django_spam'
]

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)

SITE_ID = 1
SECRET_KEY = 'fake-key'

ROOT_URLCONF = "tests.urls"

SPAM_URLS = [
    'https://www.youtube.com/watch?v=ov5pxaIbJlM',
]

SPAM_ROUTES = [
    'testadmin.php',
]

EXCLUDED_ROUTES = [
    'index.php',
]

DEBUG = True

STATIC_URL = '/static/'

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(os.path.dirname(__file__), 'database.db'),
    }
}

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]



from __future__ import absolute_import

from django.conf import settings
from django.conf.urls import url

from django_spam import SPAM_ROUTES
from django_spam.views import ten_hours


def get_spam_urls():
    spam_urls = []
    for route in SPAM_ROUTES:
        spam_urls.append(url(r'^'+route+'$', ten_hours))

    return spam_urls


urlpatterns = get_spam_urls()



from django.conf import settings

from django_spam.utils import Colour


# common endpoints bots like (w/o leading slash)
SPAM_ROUTES = [
    # asp/x
    'admin.aspx',
    'admin.asp',
    'admin/account.html',
    'admin/login.asp',
    'admin_login.asp',
    'admin_login.aspx',
    'administartorlogin.aspx',
    'administrator_login.asp',
    'administrator_login.aspx',
    'login/administrator.aspx',
    'login/admin.asp',
    # php
    'admin.php',
    'admin/login.php',
    'admin_area/index.php',
    'administrator/index.php',
    'index.php',
    'siteadmin/index.php',
    'siteadmin/login.php',
    'wp-admin/admin-ajax.php',
    'wp-admin/post-new.php',
    'wp-admin/options-link.php',
    'wp-admin/includes/themes.php',
    'wp-login.php',
    # html
    'admin/account.html',
    'admin/admin.html',
    'admin/index.html',
    'admin/login.html',

]

# '10 hours of'...
SPAM_URLS = [
    # donald trump saying bing bing bong
    'https://www.youtube.com/watch?v=UKbOqEk6rsk',
    # darth vader breathing
    'https://www.youtube.com/watch?v=un8FAjXWOBY',
    # donald trump noises
    'https://www.youtube.com/watch?v=GQPO4nmFkCI',
    # all star windows xp remix
    'https://www.youtube.com/watch?v=bKf9_gF5h5I',
    # aint nobody got time for that
    'https://www.youtube.com/watch?v=Kp9soHooisk',
    # yodelling
    'https://www.youtube.com/watch?v=Lxt0_YrQs0M',
    # whistling mullet guy
    'https://www.youtube.com/watch?v=Sbhoym9yzVQ',
    # screaming guy
    'https://www.youtube.com/watch?v=CRcYlE3i_-4'
]

# check if any settings vars have been included to add to the
# list of routes or urls
if hasattr(settings, 'SPAM_ROUTES'):
    SPAM_ROUTES += settings.SPAM_ROUTES


# check for excluded routes
if hasattr(settings, 'EXCLUDED_ROUTES'):
    for route in settings.EXCLUDED_ROUTES:
        if route in SPAM_ROUTES:
            SPAM_ROUTES.remove(route)
        else:
            print(Colour.text('Warning: "'+ route +'" is not included in django_spam.SPAM_ROUTES.', 'warn'))


if hasattr(settings, 'SPAM_URLS'):
    SPAM_URLS += settings.SPAM_URLS



from django.conf.urls import url, include
from django.http import HttpResponse


urlpatterns = [
    url(r'', include('django_spam.urls')),
    url(r'index.php$', lambda request: HttpResponse('Hello World!')),
]
